#!/bin/bash

. $(dirname $0)/config.sh


set -x
trap read debug

#
#
# FORMAT / SPL / U-BOOT / PARTITION
#
#

umount ${card}*
sleep 4s
umount ${card}*


dd if=/dev/zero of=${card} bs=1M count=1
dd if=u-boot/sunxi-spl.bin of=${card} bs=1024 seek=8
dd if=u-boot/u-boot.img of=${card} bs=1024 seek=40

if [ $allocEspace == "sys" ]; then
cat <<EOT | sfdisk --in-order -uM ${card}
8,16,c
,$(echo $(sfdisk -s /dev/sdb) "/ 1024 - 25 - 50" | bc),L
,,L
EOT
else
cat <<EOT | sfdisk --in-order -uM ${card}
8,16,c
,3680,L
,,L
EOT
fi

	

mkfs.vfat ${card}${p}1
mkfs.ext4 ${card}${p}2


#
#
# BOOT
#
#

mount ${card}${p}1 /mnt/
cp kernel/uImage /mnt/
cp script.bin /mnt/

cat <<EOT > /mnt/boot.cmd
setenv bootargs console=ttyS0,115200 root=/dev/mmcblk0p2 rootwait panic=10
fatload mmc 0 0x43000000 script.bin || ext2load mmc 0 0x43000000 boot/script.bin
fatload mmc 0 0x48000000 uImage || ext2load mmc 0 0x48000000 uImage boot/uImage
bootm 0x48000000
EOT
mkimage -C none -A arm -T script -d /mnt/boot.cmd /mnt/boot.scr


umount /mnt/

#
#
# ROOT FS
#
#

mount ${card}${p}2 /mnt/
debootstrap --arch=armhf --foreign $distro /mnt/
cp /usr/bin/qemu-arm-static /mnt/usr/bin/

echo "::LANCER::" /debootstrap/debootstrap --second-stage
chroot /mnt



# for Debian
cat <<EOT > /mnt/etc/apt/sources.list
deb http://http.debian.net/debian $distro main contrib non-free
deb-src http://http.debian.net/debian $distro main contrib non-free
deb http://http.debian.net/debian $distro-updates main contrib non-free
deb-src http://http.debian.net/debian $distro-updates main contrib non-free
deb http://security.debian.org/debian-security $distro/updates main contrib non-free
deb-src http://security.debian.org/debian-security $distro/updates main contrib non-free
EOT

cat <<EOT >> /mnt/etc/fstab
none    /tmp    tmpfs   defaults,noatime,mode=1777 0 0
# if you have a separate boot partition
${card}${p}1    /boot   vfat defaults 0 0 
EOT

cp /etc/resolv.conf /mnt/etc



cat <<END > /mnt/etc/apt/apt.conf.d/71-no-recommends
APT::Install-Recommends "0";
APT::Install-Suggests "0";
END



cat <<END > /mnt/runme.sh
#/bin/bash
#set -x
#trap read debug


export LANG=C
apt-get update

apt-get install locales
dpkg-reconfigure locales
# Choose en_US.UTF-8 for both prompts, or whatever you want.
export LANG=fr_FR.UTF-8

passwd

END
chmod 755 /mnt/runme.sh

echo "::LANCER::" /runme.sh

chroot /mnt

rm /mnt/usr/bin/qemu-arm-static /mnt/etc/resolv.conf /mnt/runme.sh

echo malinuxTablette > /mnt/etc/hostname

echo T0:2345:respawn:/sbin/getty -L ttyS0 115200 vt100 >> /mnt/etc/inittab

mkdir -p /mnt/lib/modules
rm -rf /mnt/lib/modules/
cp -rv kernel/output/lib /mnt/
umount /mnt

sync

